@@ -94,7 +94,7 @@ MODULE = 'authres'
 
 __author__  = 'Julian Mehnle, Scott Kitterman'
 __email__   = 'julian@mehnle.net'
-__version__ = '0.900'
+__version__ = '1.0.1'
 
 import authres.core
 
@@ -185,13 +185,15 @@ def all_features():
         import authres.dmarc
         import authres.smime
         import authres.rrvs
+        import authres.arc        
         _all_features = FeatureContext(
             authres.dkim_b,
             authres.dkim_adsp,
             authres.vbr,
             authres.dmarc,
             authres.smime,
-            authres.rrvs
+            authres.rrvs,
+            authres.arc
         )
     return _all_features
 
